@@ -28,9 +28,11 @@
 // Okteta core
 #include <okteta/numberrange.h>
 
-namespace Okteta {
 
-using LinePositionRange = KDE::NumberRange<LinePosition, LinePositionSize>;
+namespace Okteta
+{
+
+typedef KDE::NumberRange<LinePosition,LinePositionSize> LinePositionRange;
 
 }
 
