@@ -24,12 +24,12 @@
 
 // lib 
 #include "modelencoderfilesystemexporterconfigeditor.h"
-// Kasten core
-#include <filesystem/modelencoderfilesystemexporter.h>
 #include <abstractmodelstreamencoderconfigeditorfactory.h>
+// Kasten core
+#include <kasten/modelencoderfilesystemexporter.h>
 
 
-namespace Kasten2
+namespace Kasten
 {
 
 ModelEncoderFileSystemExporterConfigEditorFactory::ModelEncoderFileSystemExporterConfigEditorFactory( AbstractModelStreamEncoderConfigEditorFactory* encoderConfigEditorFactory )
